//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// WIRELESS MOUSETRAP MONITORING SYSTEM by Alberto Ricci Bitti (c) 2003      www.riccibitti.com
//
//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// MODULE:   HARDWARE.C
// PURPOSE:  Hides hardware-specific details from main application, initialize registers, 
//           timers, and interrupts
// REQUIRES: hardware_initialize should be the first function call in the program
// NOTES:    After call, interrupt are enabled
//
////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "radio.h"
#include "keyboard.h"
#include "hardware.h"

T_TIMEFLAGS timeflags;  //updated by timer ISR, used by main to schedule cyclic tasks



///////////////////////////////////////////////////////////////////////////////
// hardware_initialize - Initializes registes, timers, 
///////////////////////////////////////////////////////////////////////////////

void hardware_initialize(void) 
{

   OSCTRIM = Optional; 
   CONFIG1 = bin(0,0,1,0, 0,1,1,1);
   //            | | | |  | | | |
   //            | | | |  | | | +-COPD    = 1  disable COP watchdog
   //            | | | |  | | +---STOP    = 1  enable STOP instruction
   //            | | | |  | +-----SSREC   = 1  short (32 cycle) STOP recovery
   //            | | | |  +-------LVI5OR3 = 0  set LVI for 3v system
   //            | | | +----------LVIPWRD = 0  enable power to LVI system
   //            | | +------------LVIRSTD = 1  disable reset on LVI trip
   //            | +--------------LVISTOP = 0  disable LVI in STOP mode
   //            +----------------COPRS   = 0  long COP timeout


   INTSCR = 0x06;           // Disable IRQ interrupts (unused)
   PTA    = bin( 0,0,0,0, 0,0,0,0 );
   PTAPUE = bin( 0,0,1,1, 1,1,0,1 );
   DDRA   = bin( 0,0,0,0, 0,0,1,0 );
   
    //timer generates main tick frequency
    //used for updating the radio module decoder

    TMOD = CLOCK_FREQUENCY / RADIO_SAMPLING_FREQ;
    TSC_TOIE = 1;   //enable overflow interrupt
    TSC_TSTOP=0;    //start timer

    EnableInterrupts;
}


///////////////////////////////////////////////////////////////////////////////
// _TOF_Interrupt - Timer overflow interrupt service routine
// - polls radio receiver
// - polls keyboard
// - updated time flags: sets flags signalling 1/20, 1 sec, 1 min, 1 hour
///////////////////////////////////////////////////////////////////////////////

#pragma TRAP_PROC
void _TOF_Interrupt(void) 
{
    static unsigned int  prescaler = 0;
    static unsigned char twentieths = 0;    
    static unsigned char seconds = 0;   
    static unsigned char minutes = 0;   

    if(TSC_TOF == 1)
        TSC_TOF=0;
    radio_poll();
    if ( ++prescaler == ( RADIO_SAMPLING_FREQ / FREQ_20_HERTZ ) )
    {
        key_poll();

        prescaler = 0;
        timeflags.twentieth = TRUE;
        if (++twentieths == 20)
        {
            twentieths = 0;
            timeflags.second = TRUE;
            if (++seconds == 60)
            {
                seconds = 0;
                timeflags.minute = TRUE;
                if (++minutes == 60)
                {
                    minutes = 0;
                    timeflags.hour = TRUE;
                };
            };
        };
    };
}




///////////////////////////
// Ununsed interrupts    //
///////////////////////////

#pragma TRAP_PROC
void _ADC_Interrupt(void) {}

#pragma TRAP_PROC
void _KBD_Interrupt(void) {}

#pragma TRAP_PROC
void _IRQ_Interrupt(void) {}

#pragma TRAP_PROC
void _TCH0_Interrupt(void) {}

#pragma TRAP_PROC
void _TCH1_Interrupt(void) {}


