//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// WIRELESS MOUSETRAP MONITORING SYSTEM by Alberto Ricci Bitti (c) 2003      www.riccibitti.com
//
//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// HARDWARE.H
//
// Hardware register/pin configuration
//
/////////////////////////////////////////////////////////////
//
//                   MC68HC908QY4
//
//                +-------_-------+                   
//                | Vdd       Vss |                      
//                |               |                    
//         LCD D7 | PB7       PB0 | LCD R/S     
//                |               |                    
//         LCD D6 | PB6       PB1 | LCD ENABLE             
//                |               |                    
//  (BACK) KEY 4  | PA5       PA0 | ICD SERIAL
//                |               |                    
//   (FWD) KEY 1  | PA4       PA1 | KEY 0 (SETUP) / ICD                                       
//                |               |                    
//         LCD D5 | PB5       PB2 | RADIO MODULE INPUT                    
//                |               |                    
//         LCD D4 | PB4       PB3 | RELAY                     
//                |               |                    
// (STORE) KEY 3  | PA3       PA2 | KEY 2 (CLEAR) / ICD PB         
//                +---------------+
//
//
//

#ifndef HARDWARE_INCLUDED
#define HARDWARE_INCLUDED

#include <MC68HC908QY4.h>
#include <hidef.h>
#define CLOCK_FREQUENCY 3200000

/////////////////////////////////////////////////////////////////
// LCD MODULE PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define LCD_E           PTB_PTB1    // Enable (strobe) pin
#define LCD_CD          PTB_PTB0    // Command/data selector, sometimes named R/S

#define LCD_DB7         PTB_PTB7    // Data pin, bits 7..4 (other pins unconnected)
#define LCD_DB6         PTB_PTB6    //
#define LCD_DB5         PTB_PTB5    //
#define LCD_DB4         PTB_PTB4    //


#define LCD_E_DDR       DDRB_DDRB1  // data direction register bits for
#define LCD_CD_DDR      DDRB_DDRB0  // all of the pins above
                                //
#define LCD_DB7_DDR     DDRB_DDRB7  //
#define LCD_DB6_DDR     DDRB_DDRB6  //
#define LCD_DB5_DDR     DDRB_DDRB5  //
#define LCD_DB4_DDR     DDRB_DDRB4  //



/////////////////////////////////////////////////////////////////
// RADIO RECEIVER MODULE PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define RADIO_INPUT     PTB_PTB2
#define RADIO_PULLUP    PTBPUE_PTBPUE2
#define RADIO_DDR       DDRB_DDRB2



/////////////////////////////////////////////////////////////////
// KEYOBOARD PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define SETUP_INPUT     PTA_PTA1
#define STORE_INPUT     PTB_PTB3
#define FWD_INPUT       PTA_PTA4
#define BACK_INPUT      PTA_PTA5
#define CLEAR_INPUT     PTA_PTA2

#define SETUP_DDR       DDRA_DDRA1
#define STORE_DDR       DDRB_DDRB3
#define FWD_DDR         DDRA_DDRA4
#define BACK_DRR        DDRA_DDRA5
//#define CLEAR_DDR     DDRA_DDRA2  //this bit does not exist
                                    //uncomment if reassigning it

#define SETUP_PULLUP    PTAPUE_PTAPUE1
#define STORE_PULLUP    PTBPUE_PTBPUE3
#define FWD_PULLUP      PTAPUE_PTAPUE4
#define BACK_PULLUP     PTAPUE_PTAPUE5
#define CLEAR_PULLUP    PTAPUE_PTAPUE2



/////////////////////////////////////////////////////////////////
// RELAY PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define RELAY_OUTPUT    PTA_PTA3
#define RELAY_DDR       DDRA_DDRA3

#define relay_initialize() {RELAY_DDR = 1;}



/////////////////////////////////////////////////////////////////
// some useful macros when toggling bits
/////////////////////////////////////////////////////////////////

#define bin( x7, x6, x5, x4, x3, x2, x1, x0) ((x7)*128 + (x6)*64 + (x5)*32 + (x4)*16 + (x3)*8 + (x2)*4 + (x1)*2 +(x0) )

#define get_bit( x, n ) ( ( (x) & ( 1 << (n) ) ) != 0 )
#define set_bit( x, n ) { (x) |=  ( 1 << (n) ); } 
#define clr_bit( x, n ) { (x) &= ~( 1 << (n) ); } 



/////////////////////////////////////////////////////////////////
// TIMEFLAGS structure
// incremented every tweniteth of second by timer interrupt 
// routine, used by main for testing if (slow) updates are needed
/////////////////////////////////////////////////////////////////

typedef struct {
    unsigned char twentieth :1;
    unsigned char second    :1;
    unsigned char minute    :1;
    unsigned char hour      :1;
}T_TIMEFLAGS;

extern T_TIMEFLAGS timeflags;



/////////////////////////////////////////////////////////////////
// general iitialization routine
/////////////////////////////////////////////////////////////////

extern void hardware_initialize(void);


#endif