//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// WIRELESS MOUSETRAP MONITORING SYSTEM by Alberto Ricci Bitti (c) 2003      www.riccibitti.com
//
//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
//  MODULE:   KEYBOARD.C
//  PURPOSE:  Keyboard driver
//  REQUIRES: Call key_poll() every 50 mS (20 Hz) to optimize de-bounce effect
//  NOTES:    None.
//
/////////////////////////////////////////////////////////////////////////////////////////////   


#include "hardware.h"
#include "keyboard.h"


static unsigned char key = KEY_NONE;    //keyboard buffer

///////////////////////////////////////////////////////////////////////////////
//    keyboard initialization                                                //
//    sets port directions/pullups indipendently for each pin in order       //
//    to make the keyboard work with any mix of pin/port assignements        //
///////////////////////////////////////////////////////////////////////////////

void key_initialize( void )
{
    
    SETUP_DDR    = 0;                   //ensure all relevant Data Direction Registers are set for input    
    STORE_DDR    = 0;
    FWD_DDR      = 0;
    BACK_DRR     = 0;
//  CLEAR_DDR    = 0;                   //uncomment this line if the CLEAR key is connected
                                        //to a pin other than DDRA_DDRA2 (which doesn't exists)

    SETUP_PULLUP = 1;                   //turn all pullups on all key inputs
    STORE_PULLUP = 1;
    FWD_PULLUP   = 1;
    BACK_PULLUP  = 1;
    CLEAR_PULLUP = 1;
    
    key = KEY_NONE;                     //flush keyboard buffer
}



///////////////////////////////////////////////////////////////////////////////
//    keyboard polling, to be called every 50 mS ( = 20 Hz, enough time      //
//    to avoid debounce).                                                    //
//    At exit, a new keypress is reflected in the "key" variable             //
///////////////////////////////////////////////////////////////////////////////

void key_poll( void )
{
    static unsigned char pvs_key = KEY_NONE;
    unsigned char new_key = KEY_NONE;
    
    if (key == KEY_NONE)                    //is buffer empty?
    {                                       //yes, detect keypresses pin by pin

        if      ( SETUP_INPUT == 0 )    new_key = KEY_SETUP;
        else if ( CLEAR_INPUT == 0 )    new_key = KEY_CLEAR;
        else if ( FWD_INPUT   == 0 )    new_key = KEY_FWD;  
        else if ( BACK_INPUT  == 0 )    new_key = KEY_BACK; 
        else if ( STORE_INPUT == 0 )    new_key = KEY_STORE;
        else                            new_key = KEY_NONE; 
        
        if (new_key != pvs_key)             //compare current key with last key 
        {                                   //to detect any changes
            if (new_key != KEY_NONE)        //change detected, discard key-breaks
            {
                key = new_key;              //key-make found, copy it to key buffer
            }
        }

        pvs_key = new_key;                  //store current input for next round
    }
}



///////////////////////////////////////////////////////////////////////////////
//  gets last key pressed and clears keyboard buffer                         //
//  returns KEY_NONE if no key pressed                                       //
///////////////////////////////////////////////////////////////////////////////

unsigned char key_get()
{
    unsigned char retval = key;             //prepare return value
    key = KEY_NONE;                         //clear keyboard buffer
    return retval;
}