//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// WIRELESS MOUSETRAP MONITORING SYSTEM by Alberto Ricci Bitti (c) 2003      www.riccibitti.com
//
//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// MODULE:   HARDWARE.C
// PURPOSE:  Defines hardware related details, registers, timers.
//			 Defines simbolic names for the pins used
// REQUIRES: No special requirements.
// NOTES:    Runs in user-monitor mode
//
//////////////////////////////////////////////////////////////////////////////////////////////////////



#include "hardware.h"


//////////////////////////////////////////////////////////////////////////////////////////////////////
// Hardware_initialize - performs register inizialization 
//////////////////////////////////////////////////////////////////////////////////////////////////////


void hardware_initialize(void) 
{

   	OSCTRIM = Optional; 
   	CONFIG1 = bin(0,0,1,0, 0,1,1,1);
   	//            | | | |  | | | |
   	//            | | | |  | | | +-COPD    = 1  disable COP watchdog
   	//            | | | |  | | +---STOP    = 1  enable STOP instruction
   	//            | | | |  | +-----SSREC   = 1  short (32 cycle) STOP recovery
   	//            | | | |  +-------LVI5OR3 = 0  set LVI for 3v system
   	//            | | | +----------LVIPWRD = 0  enable power to LVI system
   	//            | | +------------LVIRSTD = 1  disable reset on LVI trip
   	//            | +--------------LVISTOP = 0  disable LVI in STOP mode
   	//            +----------------COPRS   = 0  long COP timeout


   	INTSCR = 0x06;          // Disable IRQ interrupts (unused)

   	REARM_PULLUP  = 1;		//initialize REARM/TEST button
	REARM_DDR     = 0;		
   	REARM_KBIE 	= 1;		//allow keyboard interrupt

   	SETUP_PULLUP = 1;		//initialize SETUP button
// 	SETUP_DDR    = 0;		//this bit does not exists on QT, uncomment if using a different pin
   	SETUP_KBIE 	= 1;		//allow keyboard interrupt	

   	REED_ENABLE;			//initialize mouse sensor (reed switch) for input
   
   	TX_PULLUP    = 0;		//initialize transmitter module
   	TX_DDR       = 1;
   	TX_OFF;
   
   	PTBPUE = 0xFF;			//set portb pullups to minimize power consuption

	PULLUP_UNUSED_PINS   

	TSC =  0x70;			//timer status and control register (TSC):
							//	TOF   =   0  clear pending interrupts flag
							//	TOIE    = 1  enable interrupt to wake up from wait mode
							//	TSTOP   = 1  stop timer count (consumes less power)
							//	TRST    = 1  reset timer to zero
							//PRESCALER = 0  do not divide base clock frequnecy

    KBSCR_MODEK  = 0;		//generate keyboard interrupts on falling edges only
	KBIER_AWUIE  = 1; 		//enable auto-wakeup
	KBSCR_IMASKK = 0;		//enable keyboard/auto wake up interrupts
	KBSCR_ACKK   = 1; 		//clear unwanted keyboard/auto wake up interrupts
}



//////////////////////////////////////////////////////////////////////////////////////////////////////
// stop_mode - puts the processor in low-power STOP mode (waiting for the autowakeup timer)
//////////////////////////////////////////////////////////////////////////////////////////////////////

void stop_mode(void)
{
		KBSCR_ACKK = 1; 		//clear keyboard/auto wake up interupt flag
    	COPCTL = 0;  			// clear the COP counter
		_asm STOP;				//put processor in STOP mode until a key is pressed,
								//trap is triggered, or auto wake interrupt happens
   		COPCTL = 0;  			//clear the COP counter again
}



//////////////////////////////////////////////////////////////////////////////////////////////////////
// _TOF_Interrupt - timer overflow ISR - does nothing, because the timer is used  exclusively
//for waking up the processor from low-power mode
//////////////////////////////////////////////////////////////////////////////////////////////////////

#pragma TRAP_PROC
void _TOF_Interrupt(void) 
{
	if(TSC_TOF == 1)			//read/set sequence required to clear flag
		TSC_TOF=0;
}



//////////////////////////////////////////////////////////////////////////////////////////////////////
// _KBD_Interrupt - keyboard interrupt ISR - does nothing, because the input is used  for waking 
// up the processor from low-power mode - The inputs are then processed from the main program
//////////////////////////////////////////////////////////////////////////////////////////////////////
#pragma TRAP_PROC
void _KBD_Interrupt(void) 
{
		KBSCR_ACKK = 1; 		//clear keyboard/auto wake up interupt flag
}



/////////////////////////////////////////////////////
// void bodies for unused interrupt vectors
/////////////////////////////////////////////////////

#pragma TRAP_PROC
void _ADC_Interrupt(void) {}

#pragma TRAP_PROC
void _IRQ_Interrupt(void) {}

#pragma TRAP_PROC
void _TCH0_Interrupt(void) {}

#pragma TRAP_PROC
void _TCH1_Interrupt(void) {}


