//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// WIRELESS MOUSETRAP MONITORING SYSTEM by Alberto Ricci Bitti (c) 2003      www.riccibitti.com
//
//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
// HARDWARE.H
//
// Hardware register/pin configuration
//
//////////////////////////////////////////////////////////////////////////////////////////////////////  
//
//                          MC68HC908QT4
//
//                       +-------_-------+                   
//                       | Vdd       Vss |                      
//                       |               |                    
//            TX MODULE  | PA5       PA0 | ICD SERIAL
//                       |               |                    
// MOUSE SENSOR REED SW. | PA4       PA1 | PWM / ICD                                       
//                       |               |                    
//        (REARM) KEY 2  | PA3       PA2 | KEY 1 (SETUP) / ICD PB         
//                       +---------------+
//
//
//

#ifndef HARDWARE_INCLUDED
#define HARDWARE_INCLUDED

//Use QY instead of QT include file in order to get the definition of
//PORT B pullup register. Altough not bounded-out on 8 pin devices, 
//this port exists on silicon. For low power applications it is 
//important to set PORTB pullups in order to keep power consuption 
//as low as possible
#include <MC68HC908QY4.h>

#include <hidef.h>

#define CLOCK_FREQ 3200000



/////////////////////////////////////////////////////////////////
// RADIO TRANSMITTER MODULE PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define TX_OUTPUT		PTA_PTA5			//input pin
#define TX_DDR			DDRA_DDRA5			//data direction register
#define TX_PULLUP		PTAPUE_PTAPUE5		//pullup enable register

#define TX_ON			{TX_OUTPUT = 1;}	//turn transimetter on
#define TX_OFF			{TX_OUTPUT = 0;}	//turn transmitter off



/////////////////////////////////////////////////////////////////
// KEYOBOARD PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define SETUP_INPUT  	PTA_PTA2			//input pin
#define SETUP_KBIE		KBIER_KBIE2			//keyboard interrupt enable register
#define SETUP_PULLUP 	PTAPUE_PTAPUE2		//pullup enable register
//#define SETUP_DDR    	DDRA_DDRA2			//data direction register
											//this bit does not exists on QT, uncomment 
											//if using a different pin
											

#define REARM_INPUT	 	PTA_PTA3			//input pin
#define REARM_KBIE		KBIER_KBIE3			//keyboard interrupt enable register
#define REARM_PULLUP 	PTAPUE_PTAPUE3		//pullup enable register
#define REARM_DDR    	DDRA_DDRA3			//data direction register



/////////////////////////////////////////////////////////////////
// REED-SWITCH MOUSE SENSOR PIN DEFINITIONS
/////////////////////////////////////////////////////////////////

#define REED_INPUT  	PTA_PTA4			//input pin

#define REED_DDR    	DDRA_DDRA4			//data direction register
#define REED_PULLUP 	PTAPUE_PTAPUE4		//pullup enable register

#define REED_OUTPUT  	REED_INPUT			//reed switch pin turns to output
											//when il ultra-low power mode
//macro to enable switch input											
#define REED_ENABLE		{  REED_PULLUP = 1; REED_DDR = 0;}

//macro to disable switch input and make it an output to save power
#define REED_DISABLE	{  REED_PULLUP = 0; REED_OUTPUT = 0; REED_DDR = 1; }

//add here any unused pin - unused pins must be pulled up in order
//to reduce current consumption
#define PULLUP_UNUSED_PINS {\
	DDRA_DDRA1 = 0;\
	DDRA_DDRA0 = 0;\
	PTAPUE_PTAPUE0 = 1;\
	PTAPUE_PTAPUE1 = 1;\
}



/////////////////////////////////////////////////////////////////
// some useful macros when toggling bits
/////////////////////////////////////////////////////////////////

#define bin( x7, x6, x5, x4, x3, x2, x1, x0) ((x7)*128 + (x6)*64 + (x5)*32 + (x4)*16 + (x3)*8 + (x2)*4 + (x1)*2 +(x0) )



/////////////////////////////////////////////////////////////////
// general initialization routine
/////////////////////////////////////////////////////////////////

extern void hardware_initialize(void);



/////////////////////////////////////////////////////////////////
// routine for putting the processor in STOP mode
/////////////////////////////////////////////////////////////////

extern void stop_mode(void);



/////////////////////////////////////////////////////////////////
// routine for putting the processor in WAIT mode
// (implemented as a macro)
/////////////////////////////////////////////////////////////////
#define WAIT_MODE 	{ _asm WAIT; }

#endif